# folding-at-home-api-python-wrapper

[![Downloads](https://pepy.tech/badge/jokeapi)](https://pepy.tech/downloads/foldingathome)

This is a Python wrapper for Folding@Home's statistics APIs.

With this wrapper, you can access team and donor information.
